@@ -8,6 +8,8 @@ Compute functions (:mod:`sknano.structures._compute_funcs`)
 
 """
 from __future__ import absolute_import, division, print_function
+import six
+from six.moves import range
 __docformat__ = 'restructuredtext en'
 
 from fractions import gcd
@@ -180,7 +182,7 @@ def compute_t2(n, m):
 
 
 def compute_Ch(n, m, bond=None, **kwargs):
-    u"""Compute nanotube circumference :math:`|\\mathbf{C}_{h}|` in
+    six.u("""Compute nanotube circumference :math:`|\\mathbf{C}_{h}|` in
     **\u212b**.
 
     .. math::
@@ -204,7 +206,7 @@ def compute_Ch(n, m, bond=None, **kwargs):
     float
         Nanotube circumference :math:`|\\mathbf{C}_h|` in \u212b.
 
-    """
+    """)
     if not (isinstance(n, numbers.Real) or n >= 0):
         raise TypeError('Expected an integer')
     if not (isinstance(m, numbers.Real) or m >= 0):
@@ -250,7 +252,7 @@ def compute_chiral_angle(n, m, rad2deg=True):
 
 
 def compute_T(n, m, bond=None, length=True, **kwargs):
-    u"""Compute length of nanotube unit cell :math:`|\\mathbf{T}|` in
+    six.u("""Compute length of nanotube unit cell :math:`|\\mathbf{T}|` in
     \u212b.
 
     .. math::
@@ -282,7 +284,7 @@ def compute_T(n, m, bond=None, length=True, **kwargs):
         translation vector as a 2-tuple of ints
         (:math:`t_1`, :math:`t_2`).
 
-    """
+    """)
     if not (isinstance(n, numbers.Real) or n >= 0):
         raise TypeError('Expected an integer')
     if not (isinstance(m, numbers.Real) or m >= 0):
@@ -307,7 +309,7 @@ def compute_T(n, m, bond=None, length=True, **kwargs):
 
 
 def compute_dt(n, m, bond=None, **kwargs):
-    u"""Compute nanotube diameter :math:`d_t` in \u212b.
+    six.u("""Compute nanotube diameter :math:`d_t` in \u212b.
 
     .. math::
 
@@ -329,7 +331,7 @@ def compute_dt(n, m, bond=None, **kwargs):
     float
         Nanotube diameter :math:`d_t` in \u212b.
 
-    """
+    """)
     if not (isinstance(n, numbers.Real) or n >= 0):
         raise TypeError('Expected an integer')
     if not (isinstance(m, numbers.Real) or m >= 0):
@@ -340,7 +342,7 @@ def compute_dt(n, m, bond=None, **kwargs):
 
 
 def compute_rt(n, m, bond=None, **kwargs):
-    u"""Compute nanotube radius :math:`r_t` in \u212b.
+    six.u("""Compute nanotube radius :math:`r_t` in \u212b.
 
     .. math::
 
@@ -363,7 +365,7 @@ def compute_rt(n, m, bond=None, **kwargs):
     float
         Nanotube radius :math:`r_t` in \u212b.
 
-    """
+    """)
     if not (isinstance(n, numbers.Real) or n >= 0):
         raise TypeError('Expected an integer')
     if not (isinstance(m, numbers.Real) or m >= 0):
@@ -401,7 +403,7 @@ def compute_M(n, m):
 
 
 def compute_R(n, m, bond=None, length=False, **kwargs):
-    u"""Compute symmetry vector :math:`\\mathbf{R} = (p, q)`.
+    six.u("""Compute symmetry vector :math:`\\mathbf{R} = (p, q)`.
 
     The *symmetry vector* is any lattice vector of the unfolded graphene
     layer that represents a *symmetry operation* of the nanotube. The
@@ -442,7 +444,7 @@ def compute_R(n, m, bond=None, length=False, **kwargs):
         Length of :math:`\\mathbf{R}` (:math:`|\\mathbf{R}|`) if `length`
         is `True` in units of **\u212b**.
 
-    """
+    """)
     if not (isinstance(n, numbers.Real) or n >= 0):
         raise TypeError('Expected an integer')
     if not (isinstance(m, numbers.Real) or m >= 0):
@@ -453,8 +455,8 @@ def compute_R(n, m, bond=None, length=False, **kwargs):
     t2 = compute_t2(n, m)
 
     p = q = 0
-    for i in xrange(0, t1 + n + 1):
-        for j in xrange(t2, m + 1):
+    for i in range(0, t1 + n + 1):
+        for j in range(t2, m + 1):
             R = t1 * j - t2 * i
             if R == 1:
                 M = m * i - n * j
@@ -508,7 +510,7 @@ def compute_R_chiral_angle(n, m, rad2deg=True):
 
 
 def compute_symmetry_operation(n, m, bond=None):
-    u"""Compute symmetry operation :math:`(\\psi|\\tau)`.
+    six.u("""Compute symmetry operation :math:`(\\psi|\\tau)`.
 
     The *symmetry vector* `R` represents a *symmetry
     operation* of the nanotube which arises as a *screw translation*, which
@@ -537,7 +539,7 @@ def compute_symmetry_operation(n, m, bond=None):
         2-tuple of floats -- :math:`\\psi` in radians and
         :math:`\\tau` in \u212b.
 
-    """
+    """)
     if not (isinstance(n, numbers.Real) or n >= 0):
         raise TypeError('Expected an integer')
     if not (isinstance(m, numbers.Real) or m >= 0):
@@ -582,7 +584,7 @@ def compute_psi(n, m):
 
 
 def compute_tau(n, m, bond=None, **kwargs):
-    u"""Compute translation component of symmetry operation
+    six.u("""Compute translation component of symmetry operation
     :math:`\\tau` in **\u212b**.
 
     .. math::
@@ -606,7 +608,7 @@ def compute_tau(n, m, bond=None, **kwargs):
         Translation component of symmetry operation :math:`\\tau`
         in **\u212b**.
 
-    """
+    """)
     if not (isinstance(n, numbers.Real) or n >= 0):
         raise TypeError('Expected an integer')
     if not (isinstance(m, numbers.Real) or m >= 0):
@@ -860,7 +862,7 @@ def compute_linear_mass_density(n, m, bond=None, element1=None, element2=None,
 
 def compute_bundle_density(n, m, d_vdw=None, bond=None,
                            element1=None, element2=None):
-    u"""Compute nanotube bundle mass density
+    six.u("""Compute nanotube bundle mass density
     :math:`\\rho_{\\mathrm{bundle}}(n, m)` in :math:`\\mathrm{g/cm^3}`.
 
     .. math::
@@ -886,7 +888,7 @@ def compute_bundle_density(n, m, d_vdw=None, bond=None,
         :math:`\\rho_{\\mathrm{bundle}}` in units of
         :math:`\\mathrm{\\frac{g}{cm^3}}`
 
-    """
+    """)
     if bond is None:
         bond = CCbond
 
